{{      short program to setup and test propeller chip to MAXIM-7219 alpha-numeric LED
        driver chip to a 6-digit LED display on propeller professional dev. board  (PPDB)
        Parallax part #32111.

        In setting up the circuit, I connected a 10K-ohm resistor from pin 12 of the max-7219 to GND
                                                 10K-ohm resistor from pin 18 of the max-7219 to +5v
                                                 10 uF electrolytic & .1uF mono cap (in parallel)
                                                 across the +5V and GND pins of the max-7219.

        Be sure to use jumper wires on A1_A2, D1,D2, G1,G2 LED segment pairs on the PPDB to the a_pin, d-pin G-pin
        of the max-7219.

        The propeller to max-7219 connections are indicated in the CON section.

        Make sure to have the SPIN code "BS2_functions.spin" in the same location as this code.                                               

        If everything is wired right and this code is sent to the PPBD, the 6-digit display
        should show:   1. 2 3. 4 5. 6
}}
CON
'       clock mode & timing constants

    _clkmode    = xtal1 + pll16x       'set for 80 MHZ clock
    _xinfreq    = 5_000_000            '5 MHZ crystal in propeller chip circuit
    full_sec    = 80_000_000           'full second delay
    hund_sec    = 800_000              '1 second / 100

'      MAXIM-7219 7-segment LED display driver connections to prop chip

    data_7219   = 7                    'DIN - data in pin to pin 1 of MAX-7219
    Clok_7219   = 8                    'clock signal in pin to pin 13 of MAX-7219
    load_7219   = 9                    'load pulse in pin to pin 12 of MAX-7219

'       DEBUG pins

    rx__pin     = 31                   'pin to receive a serial data signal (from prop plug)
    tx__pin     = 30                   'pin to send a serial data signal (to prop plug)

'      MAX-7219 register names

    digit_0         = 1
    digit_1         = 2
    digit_2         = 3
    digit_3         = 4
    digit_4         = 5
    digit_5         = 6            
    digit_6         = 7              'These 2 digits not used on Propeller Professional developement board
    digit_7         = 8              'because it uses only 6 digits 5 -  0

    bdecode         = 9              'Sets up BCD decoding for each digit
    brite           = 10             'Sets up LED 7-segment display brightness level
    scan            = 11             'sets up number of digits to be scanned
                                     '= number of digits - 1
    shutdn          = 12             'shut down 7-segment LED display
    display_test    = 15             'light up all LED 7-segment digits

    blank           = %1111          'MAX-7219 display code for a blank digit
    minus           = %1010          'MAX-7219 display code for a minus (-).
    DP              = %10000000      'decimal point

OBJ

    BS2           : "BS2_Functions"    ' Create BS2 Object

VAR

    word  index
    byte  pntr_7219                    'index to location in MAX-7219 to write data to
    byte  char_7219                    'data to be sent to the MAX-7219

PUB     setup_and_test_M7219

    BS2.start (rx__pin,tx__pin)        'Initialize BS2 Object timing, Rx and Tx pins for optional BS2 style DEBUG 
    dira[load_7219]~~                  'setup prop pins 7-9
    dira[clok_7219]~~                  'as outputs
    dira[data_7219]~~                  'to MAX_7219

    outa[load_7219]~                   'make the output pins low
    outa[clok_7219]~                   '
    outa[data_7219]~                   '

    repeat index from 0 to 4
      pntr_7219 := m7219_presets_pointers[index]
      char_7219 := m7219_presets_values[index]
      chrout_to_7219

    repeat index from digit_0 to digit_5  'blank all
      pntr_7219 := index                  '6 digits
      char_7219 := blank                  'on the PPDB
      chrout_to_7219

    pntr_7219 := digit_5    'digit location DS1 L
    char_7219 := 1 + DP      '  "1."
    chrout_to_7219
      
    pntr_7219 := digit_4    'digit location DS1 R
    char_7219 := 2          '   "2"
    chrout_to_7219

    pntr_7219 := digit_3    'digit location DS2 L
    char_7219 := 3 + DP     '   "3."
    chrout_to_7219

    pntr_7219 := digit_2    'digit location DS2 R
    char_7219 := 4          '   "4"
    chrout_to_7219

    pntr_7219 := digit_1    'digit location DS3 l
    char_7219 := 5 + DP     '   "5."
    chrout_to_7219

    pntr_7219 := digit_0    'digit location DS3 R
    char_7219 := 6          '   "6"
    chrout_to_7219


PUB     chrout_to_7219

    BS2.SHIFTOUT(data_7219,clok_7219,pntr_7219,BS2#MSBFIRST,8)
    BS2.SHIFTOUT(data_7219,clok_7219,char_7219,BS2#MSBFIRST,8)
    BS2.PULSOUT(load_7219,20)
          
DAT

'       MAX-7219 register presets

m7219_presets_pointers
        byte  scan
        byte  brite
        byte  bdecode
        byte  shutdn
        byte  display_test

m7219_presets_values
        byte  5                        '6 digits to be used
        byte  15                       'full brightness
        byte  %00111111                '6 digits all BCD decoded
        byte  1                        'shutdown off
        byte  0                        'digits/segments test off


      
      